Module dts::de

source ·
This module provides a Deserializer which supports deserializing input data with various encodings into a Value.

Structs

  • Options for the Deserializer. The options are context specific and may only be honored when deserializing from a certain Encoding.
  • A Deserializer can deserialize input data from a reader into a Value.
  • A DeserializerBuilder can be used to build a Deserializer with certain DeserializeOptions.