This module provides a Deserializer which supports deserializing input data with various
encodings into a Value.
Structs
- Options for the
Deserializer. The options are context specific and may only be honored when deserializing from a certainEncoding. - A
Deserializercan deserialize input data from a reader into aValue. - A
DeserializerBuildercan be used to build aDeserializerwith certainDeserializeOptions.